pystagram.graph_api package — pystagram 0.1 documentation

# pystagram.graph_api package

## Subpackages

- pystagram.graph_api.components package
  - Subpackages
    - pystagram.graph_api.components.breakdown package
      - Submodules
      - pystagram.graph_api.components.breakdown.breakdown module
      - Module contents
    - pystagram.graph_api.components.containers package
      - Submodules
      - pystagram.graph_api.components.containers.base_container module
      - pystagram.graph_api.components.containers.carousel_container module
      - pystagram.graph_api.components.containers.image_container module
      - pystagram.graph_api.components.containers.reel_container module
      - pystagram.graph_api.components.containers.video_container module
      - Module contents
    - pystagram.graph_api.components.fields package
      - Submodules
      - pystagram.graph_api.components.fields.account_fields module
      - pystagram.graph_api.components.fields.base_fields module
      - pystagram.graph_api.components.fields.catalog_fields module
      - pystagram.graph_api.components.fields.comment_fields module
      - pystagram.graph_api.components.fields.container_fields module
      - pystagram.graph_api.components.fields.fields module
      - pystagram.graph_api.components.fields.hashtag_fields module
      - pystagram.graph_api.components.fields.me_fields module
      - pystagram.graph_api.components.fields.media_fields module
      - pystagram.graph_api.components.fields.publishing_limit_fields module
      - pystagram.graph_api.components.fields.user_fields module
      - Module contents
    - pystagram.graph_api.components.media_type package
      - Submodules
      - pystagram.graph_api.components.media_type.media_type module
      - Module contents
    - pystagram.graph_api.components.metrics package
      - Submodules
      - pystagram.graph_api.components.metrics.album_metrics module
      - pystagram.graph_api.components.metrics.base_metrics module
      - pystagram.graph_api.components.metrics.insight_metrics module
      - pystagram.graph_api.components.metrics.media_metrics module
      - pystagram.graph_api.components.metrics.metrics module
      - pystagram.graph_api.components.metrics.reel_metrics module
      - pystagram.graph_api.components.metrics.story_metrics module
      - Module contents
    - pystagram.graph_api.components.periods package
      - Submodules
      - pystagram.graph_api.components.periods.periods module
      - Module contents
    - pystagram.graph_api.components.tag package
      - Submodules
      - pystagram.graph_api.components.tag.product_tag module
      - pystagram.graph_api.components.tag.tag module
      - pystagram.graph_api.components.tag.user_tag module
      - Module contents
  - Module contents
- pystagram.graph_api.endpoints package
  - Subpackages
    - pystagram.graph_api.endpoints.comment package
      - Submodules
      - pystagram.graph_api.endpoints.comment.comment module
      - pystagram.graph_api.endpoints.comment.replies module
      - Module contents
    - pystagram.graph_api.endpoints.container package
      - Submodules
      - pystagram.graph_api.endpoints.container.container module
      - Module contents
    - pystagram.graph_api.endpoints.hashtag package
      - Submodules
      - pystagram.graph_api.endpoints.hashtag.hashtag module
      - pystagram.graph_api.endpoints.hashtag.recent_media module
      - pystagram.graph_api.endpoints.hashtag.search module
      - pystagram.graph_api.endpoints.hashtag.top_media module
      - Module contents
    - pystagram.graph_api.endpoints.me package
      - Submodules
      - pystagram.graph_api.endpoints.me.accounts module
      - pystagram.graph_api.endpoints.me.me module
      - Module contents
    - pystagram.graph_api.endpoints.media package
      - Submodules
      - pystagram.graph_api.endpoints.media.children module
      - pystagram.graph_api.endpoints.media.collaborators module
      - pystagram.graph_api.endpoints.media.comments module
      - pystagram.graph_api.endpoints.media.insights module
      - pystagram.graph_api.endpoints.media.media module
      - pystagram.graph_api.endpoints.media.product_tags module
      - Module contents
    - pystagram.graph_api.endpoints.oauth package
      - Subpackages
      - Submodules
      - pystagram.graph_api.endpoints.oauth.oauth module
      - Module contents
    - pystagram.graph_api.endpoints.user package
      - Submodules
      - pystagram.graph_api.endpoints.user.available_catalogs module
      - pystagram.graph_api.endpoints.user.business_discovery module
      - pystagram.graph_api.endpoints.user.catalog_product_search module
      - pystagram.graph_api.endpoints.user.content_publishing_limit module
      - pystagram.graph_api.endpoints.user.insights module
      - pystagram.graph_api.endpoints.user.live_media module
      - pystagram.graph_api.endpoints.user.media module
      - pystagram.graph_api.endpoints.user.media_publish module
      - pystagram.graph_api.endpoints.user.mentionned_comment module
      - pystagram.graph_api.endpoints.user.mentionned_media module
      - pystagram.graph_api.endpoints.user.mentions module
      - pystagram.graph_api.endpoints.user.product_appeal module
      - pystagram.graph_api.endpoints.user.recently_searched_hashtags module
      - pystagram.graph_api.endpoints.user.stories module
      - pystagram.graph_api.endpoints.user.tags module
      - pystagram.graph_api.endpoints.user.user module
      - Module contents
  - Module contents

## Submodules

## pystagram.graph_api.graph_api module

Instagram Graph API

The Instagram Graph API allows users of your app to access data in their [Instagram Business](https://business.instagram.com/) and [Instagram Creator](https://help.instagram.com/2358103564437429) accounts. The API can be used to get and publish their media, manage and reply to comments on their media, identify media where they have been @mentioned by components Instagram users, find hashtagged media, and get basic metadata and metrics about components Instagram Businesses and Creators.

class pystagram.graph_api.graph_api.InstagramGraphApi(app_id: int, app_secret: str, access_token: str | None = None, base_uri: str | None = 'graph.facebook.com', api_version: str | None = 'v18.0')

  Bases: `InstagramBaseApiClient`

  Client for making requests to the Instagram Graph API. It extends the `pystagram.helpers.api_client.base_api_client.InstagramBaseApiClient` class.

  Parameters:

    - app_id (int) – The app ID of the Instagram app.

    - app_secret (str) – The app secret of the Instagram app.

    - access_token (str, optional) – The access token of the Instagram app, defaults to None

    - base_uri (str, optional) – The base URL of the Instagram Graph API, defaults to BASE_URI

    - api_version (str, optional) – The version of the Instagram Graph API, defaults to API_VERSION

  API_VERSION: str = 'v18.0'

    The version of the Instagram Graph API.

  BASE_URI: str = 'graph.facebook.com'

    The base URL of the Instagram Graph API.

  MAX_PAGES: int = 5

    The maximum number of pages to get from paginated endpoints.

  property comment

    The Comment node of the Instagram Graph API. See the `pystagram.graph_api.endpoints.comment.comment.Comment` class for additional details.

  property container

    The Container node of the Instagram Graph API. See the `pystagram.graph_api.endpoints.container.container.Container` class for additional details.

  get_user_id()

    Get the user ID of the Instagram user.

    Returns:

      The user ID of the Instagram user.

    Return type:

      str

  property hashtag

    The Hashtag node of the Instagram Graph API. See the `pystagram.graph_api.endpoints.hashtag.hashtag.Hashtag` class for additional details.

  property hashtag_search

    The HashtagSearch node of the Instagram Graph API. See the `pystagram.graph_api.endpoints.hashtag_search.HashtagSearch` class for additional details.

  property me

    The Me node of the Instagram Graph API. See the `pystagram.graph_api.endpoints.me.me.Me` class for additional details.

  property media

    The Media node of the Instagram Graph API. See the `pystagram.graph_api.endpoints.media.media.Media` class for additional details.

  property oauth

    The OAuth node of the Instagram Graph API. See the `pystagram.graph_api.endpoints.oauth.oauth.Oauth` class for additional details.

  property user

    The User node of the Instagram Graph API. See the `pystagram.graph_api.endpoints.user.user.User` class for additional details.

  property user_id

    The user ID of the Instagram user. The user id is fetched from the Instagram Graph API if it is not already set.

## Module contents